$:.unshift(File.dirname(__FILE__)) unless
  $:.include?(File.dirname(__FILE__)) || $:.include?(File.expand_path(File.dirname(__FILE__)))

require 'cgi'
require 'openssl'
require 'rbconfig'
require 'socket'
require 'uri'

require 'excon/connection'
require 'excon/errors'
require 'excon/response'

module Excon

  unless const_defined?(:VERSION)
    VERSION = '0.4.0'
  end

  unless const_defined?(:CHUNK_SIZE)
    CHUNK_SIZE = 1048576 # 1 megabyte
  end

  def self.ssl_ca_path
    @ssl_ca_path
  end

  def self.ssl_ca_path=(new_ssl_ca_path)
    @ssl_ca_path = new_ssl_ca_path
  end

  # setup ssl defaults based on platform
  case Config::CONFIG['host_os']
  when /mswin|win32|dos|cygwin|mingw/i
    @ssl_verify_peer = false
  else
    @ssl_verify_peer = true
  end

  # Status of ssl peer verification
  def self.ssl_verify_peer
    @ssl_verify_peer
  end

  # change the status of ssl peer verification
  def self.ssl_verify_peer=(new_ssl_verify_peer)
    @ssl_verify_peer = new_ssl_verify_peer
  end

  # @see Connection#initialize
  #  Initializes a new keep-alive session for a given remote host
  #
  #   @param [String] url The destination URL
  #   @param [Hash<Symbol, >] params One or more option params to set on the Connection instance
  #   @return [Connection] A new Excon::Connection instance
  def self.new(url, params = {})
    Excon::Connection.new(url, params)
  end

  %w{connect delete get head options post put trace}.each do |method|
    eval <<-DEF
      def self.#{method}(url, params = {}, &block)
        new(url).request(params.merge!(:method => :#{method}), &block)
      end
    DEF
  end

end
